==> 0.1.0.tar.gz: lib/src/schedule_package.dart <==
import 'package:html/parser.dart' show parse;
import 'package:schedule_package/src/ScheduleModels/Results.dart';
import 'package:schedule_package/src/ScheduleModels/Schedule.dart';
import 'package:schedule_package/src/ScheduleModels/ScheduleWeek.dart';
import 'package:schedule_package/src/Supports/Decoder.dart';
import 'package:universal_html/parsing.dart' show parseHtmlDocument;

import '../src/ScheduleModels/Group.dart';
import "package:http/http.dart" as http;

import '../src/Supports/GlobalVariable.dart';

// Получает все группы которые есть на сайте
Future<List<Group>> getAllGroupsFuture() async {
  List<Group> groupsList = [];
  final response =
      await http.Client().get(Uri.parse(GlobalVariable.URL_MAIN + "/cg.htm"));
  if (response.statusCode == 200) {
    var body = decodeCp1251(response.body);
    var document = parse(body, encoding: 'windows-1251');
    var table = document
        .getElementsByClassName("inf")[0]
        .getElementsByTagName("tbody")[0];
    var res = table.getElementsByTagName("tr").length - 1;
    for (int i = 1; i <= res; i++) {
      var nameGroup = table
          .getElementsByTagName("tr")[i]
          .getElementsByTagName("td")[1]
          .text;
      var linkGroup = table
          .getElementsByTagName("tr")[i]
          .getElementsByTagName("td")[1]
          .getElementsByTagName("a")[0]
          .attributes;
      groupsList.add(Group(nameGroup, linkGroup["href"].toString()));
    }
  }
  return groupsList;
}

//Получает расписание группы по его Линку (ID)
Future<List<ScheduleWeek>> getScheduleWeekFuture(String groupLink) async {
  List<ScheduleWeek> scheduleWeekList = [];
  List<Schedule> scheduleList = [];
  final response =
      await http.Client().get(Uri.parse(GlobalVariable.URL_MAIN + groupLink));
  if (response.statusCode == 200) {
    var body = decodeCp1251(response.body);
    var documentFullHtmlCode = parseHtmlDocument(body);
    var documentTableHtmlCode =
        documentFullHtmlCode.querySelectorAll("table.inf").first;
    var documentTableElements = documentTableHtmlCode.querySelectorAll("tr");
    int count = documentTableElements.length;
    for (int i = 3; i <= count - 1; i += 7) {
      if (i + 6 <= 100) {
        for (int j = 0; j <= 5; j++) {
          var documentTableSelected = documentTableElements[i + j];
          String firstLesson = "",
              firstCabinet = "",
              firstTeacher = "",
              dayParams = "";
          int countDouble =
              documentTableSelected.querySelectorAll("tr > td.ur").length;

          if (documentTableSelected.querySelector("tr > td.hd") != null)
            dayParams =
                documentTableSelected.querySelector("tr > td.hd")!.text!;
          if (documentTableSelected.querySelector("tr > td.ur > a.z1") != null)
            firstLesson =
                documentTableSelected.querySelector("tr > td.ur > a.z1")!.text!;
          if (documentTableSelected.querySelector("tr > td.ur > a.z2") != null)
            firstCabinet =
                documentTableSelected.querySelector("tr > td.ur > a.z2")!.text!;
          if (documentTableSelected.querySelector("tr > td.ur > a.z3") != null)
            firstTeacher =
                documentTableSelected.querySelector("tr > td.ur > a.z3")!.text!;

          if (isFirstElement(dayParams)) {
            if (countDouble == 2) {
              scheduleList.add(new Schedule(dayParams, firstLesson,
                  firstCabinet, firstTeacher, "", true, true, false, "1"));
            } else {
              scheduleList.add(new Schedule(dayParams, firstLesson,
                  firstCabinet, firstTeacher, "", true, true, false, "1"));
            }
            print(dayParams);
          } else if (dayParams == "2" || dayParams == "4" || dayParams == "6") {
            print(firstLesson);
            scheduleList.add(new Schedule(dayParams, firstLesson, firstCabinet,
                firstTeacher, "", false, false, true, dayParams));
          } else {
            print(firstLesson);
            if (countDouble == 2) {
              scheduleList.add(new Schedule(
                  dayParams,
                  firstLesson,
                  firstCabinet,
                  firstTeacher,
                  "",
                  false,
                  true,
                  false,
                  dayParams));
            } else {
              print(firstLesson);
              scheduleList.add(new Schedule(
                  dayParams,
                  firstLesson,
                  firstCabinet,
                  firstTeacher,
                  "",
                  false,
                  false,
                  false,
                  dayParams));
            }
          }
        }
        scheduleWeekList.add(ScheduleWeek(scheduleList));
        scheduleList = [];
      }
    }
  }
  return scheduleWeekList;
}

Future<List<Results>> getScheduleResultsFuture(String groupLink) async {
  List<Results> resultList = [];
  final response =
      await http.Client().get(Uri.parse(GlobalVariable.URL_MAIN + groupLink));
  if (response.statusCode == 200) {
    var body = decodeCp1251(response.body);
    var documentFullHtmlCode = parseHtmlDocument(body);
    var documentTableHtmlCode =
        documentFullHtmlCode.querySelectorAll("table.inf").first;
    var documentTableElements = documentTableHtmlCode.querySelectorAll("tr");
    int count = documentTableElements.length;
    for (int i = 1; i <= count - 1; i++) {
      var documentTableSelected = documentTableElements[i];
      var documentNode = documentTableSelected.querySelectorAll("td");
      resultList.add(Results(
          documentNode[0].text ?? "",
          documentNode[4].text ?? "",
          documentNode[1].text ?? "",
          documentNode[5].text ?? "",
          int.parse(documentNode[6].text ?? ""),
          int.parse(documentNode[9].text ?? ""),
          documentNode[12].text ?? "",
          int.parse(
              documentNode[13].children[0].attributes.values.elementAt(3))));
    }
  }

  return resultList;
}

//Определяет первый ли это элемент в списке
bool isFirstElement(String str) {
  if (str.contains("Пн") ||
      str.contains("Вт") ||
      str.contains("Ср") ||
      str.contains("Чт") ||
      str.contains("Пт") ||
      str.contains("Сб") ||
      str.contains("Вс")) {
    return true;
  }
  return false;
}

==> 0.1.2.tar.gz: lib/src/schedule_package.dart <==
import 'package:html/parser.dart' show parse;
import 'package:schedule_package/src/ScheduleModels/Results.dart';
import 'package:schedule_package/src/ScheduleModels/Schedule.dart';
import 'package:schedule_package/src/ScheduleModels/ScheduleWeek.dart';
import 'package:schedule_package/src/Supports/Decoder.dart';
import 'package:universal_html/parsing.dart' show parseHtmlDocument;

import '../src/ScheduleModels/Group.dart';
import "package:http/http.dart" as http;

import '../src/Supports/GlobalVariable.dart';

// Получает все группы которые есть на сайте
Future<List<Group>> getAllGroupsFuture() async {
  List<Group> groupsList = [];
  final response =
      await http.Client().get(Uri.parse(GlobalVariable.URL_MAIN + "/cg.htm"));
  if (response.statusCode == 200) {
    var body = decodeCp1251(response.body);
    var document = parse(body, encoding: 'windows-1251');
    var table = document
        .getElementsByClassName("inf")[0]
        .getElementsByTagName("tbody")[0];
    var res = table.getElementsByTagName("tr").length - 1;
    for (int i = 1; i <= res; i++) {
      var nameGroup = table
          .getElementsByTagName("tr")[i]
          .getElementsByTagName("td")[1]
          .text;
      var linkGroup = table
          .getElementsByTagName("tr")[i]
          .getElementsByTagName("td")[1]
          .getElementsByTagName("a")[0]
          .attributes;
      groupsList.add(Group(nameGroup, linkGroup["href"].toString()));
    }
  }
  return groupsList;
}

//Получает расписание группы по его Линку (ID)
Future<List<ScheduleWeek>> getScheduleWeekFuture(String groupLink) async {
  List<ScheduleWeek> scheduleWeekList = [];
  List<Schedule> scheduleList = [];
  final response =
      await http.Client().get(Uri.parse(GlobalVariable.URL_MAIN + groupLink));
  if (response.statusCode == 200) {
    var body = decodeCp1251(response.body);
    var documentFullHtmlCode = parseHtmlDocument(body);
    var documentTableHtmlCode =
        documentFullHtmlCode.querySelectorAll("table.inf").first;
    var documentTableElements = documentTableHtmlCode.querySelectorAll("tr");
    int count = documentTableElements.length;
    for (int i = 3; i <= count - 1; i += 7) {
      if (i + 6 <= 100) {
        for (int j = 0; j <= 5; j++) {
          var documentTableSelected = documentTableElements[i + j];
          String firstLesson = "",
              firstCabinet = "",
              firstTeacher = "",
              dayParams = "";

          String secondLesson = "", secondTeacher = "", secondCabinet = "";

          int countDouble =
              documentTableSelected.querySelectorAll("tr > td").length;

          if (documentTableSelected.querySelector("tr > td.hd") != null)
            dayParams =
                documentTableSelected.querySelector("tr > td.hd")!.text!;
          if (documentTableSelected.querySelector("tr > td.ur > a.z1") != null)
            firstLesson =
                documentTableSelected.querySelector("tr > td.ur > a.z1")!.text!;
          if (documentTableSelected.querySelector("tr > td.ur > a.z2") != null)
            firstCabinet =
                documentTableSelected.querySelector("tr > td.ur > a.z2")!.text!;
          if (documentTableSelected.querySelector("tr > td.ur > a.z3") != null)
            firstTeacher =
                documentTableSelected.querySelector("tr > td.ur > a.z3")!.text!;

          if (isFirstElement(dayParams)) {

            if (countDouble == 4) {
              if (documentTableSelected
                      .querySelector("tr > td.ur:last-child > a.z1") !=
                  null)
                secondLesson = documentTableSelected
                    .querySelector("tr > td.ur:last-child > a.z1")!
                    .text!;
              if (documentTableSelected
                      .querySelector("tr > td.ur:last-child > a.z2") !=
                  null)
                secondCabinet = documentTableSelected
                    .querySelector("tr > td.ur:last-child > a.z2")!
                    .text!;
              if (documentTableSelected
                      .querySelector("tr > td.ur:last-child > a.z3") !=
                  null)
                secondTeacher = documentTableSelected
                    .querySelector("tr > td.ur:last-child > a.z3")!
                    .text!;
            }

            scheduleList.add(new Schedule(
                dayParams,
                firstLesson,
                firstCabinet,
                firstTeacher,
                "",
                true,
                countDouble == 4,
                false,
                "1",
                secondLesson,
                secondTeacher,
                secondCabinet));
          } else {

            if (countDouble == 3) {
              if (documentTableSelected
                  .querySelector("tr > td.ur:last-child > a.z1") !=
                  null)
                secondLesson = documentTableSelected
                    .querySelector("tr > td.ur:last-child > a.z1")!
                    .text!;
              if (documentTableSelected
                  .querySelector("tr > td.ur:last-child > a.z2") !=
                  null)
                secondCabinet = documentTableSelected
                    .querySelector("tr > td.ur:last-child > a.z2")!
                    .text!;
              if (documentTableSelected
                  .querySelector("tr > td.ur:last-child > a.z3") !=
                  null)
                secondTeacher = documentTableSelected
                    .querySelector("tr > td.ur:last-child > a.z3")!
                    .text!;
            }

            if (j == 1) {
              scheduleList.add(new Schedule(
                  dayParams,
                  firstLesson,
                  firstCabinet,
                  firstTeacher,
                  "",
                  false,
                  countDouble == 3,
                  false,
                  dayParams,
                  secondLesson,
                  secondTeacher,
                  secondCabinet));
              scheduleList.add(new Schedule(
                  dayParams,
                  "Обеденный перерыв",
                  "гулйяте",
                  "желудок",
                  "",
                  false,
                  false,
                  true,
                  dayParams,
                  secondLesson,
                  secondTeacher,
                  secondCabinet));
            } else {
              scheduleList.add(new Schedule(
                  dayParams,
                  firstLesson,
                  firstCabinet,
                  firstTeacher,
                  "",
                  false,
                  countDouble == 3,
                  false,
                  dayParams,
                  secondLesson,
                  secondTeacher,
                  secondCabinet));
            }
          }
        }
        scheduleWeekList.add(ScheduleWeek(scheduleList));
        scheduleList = [];
      }
    }
  }
  return scheduleWeekList;
}

Future<List<Results>> getScheduleResultsFuture(String groupLink) async {
  List<Results> resultList = [];
  final response =
      await http.Client().get(Uri.parse(GlobalVariable.URL_MAIN + groupLink));
  if (response.statusCode == 200) {
    var body = decodeCp1251(response.body);
    var documentFullHtmlCode = parseHtmlDocument(body);
    var documentTableHtmlCode =
        documentFullHtmlCode.querySelectorAll("table.inf").first;
    var documentTableElements = documentTableHtmlCode.querySelectorAll("tr");
    int count = documentTableElements.length;
    for (int i = 1; i <= count - 1; i++) {
      var documentTableSelected = documentTableElements[i];
      var documentNode = documentTableSelected.querySelectorAll("td");
      resultList.add(Results(
          documentNode[0].text ?? "",
          documentNode[4].text ?? "",
          documentNode[1].text ?? "",
          documentNode[5].text ?? "",
          int.parse(documentNode[6].text ?? ""),
          int.parse(documentNode[9].text ?? ""),
          documentNode[12].text ?? "",
          int.parse(
              documentNode[13].children[0].attributes.values.elementAt(3))));
    }
  }

  return resultList;
}

//Определяет первый ли это элемент в списке
bool isFirstElement(String str) {
  if (str.contains("Пн") ||
      str.contains("Вт") ||
      str.contains("Ср") ||
      str.contains("Чт") ||
      str.contains("Пт") ||
      str.contains("Сб") ||
      str.contains("Вс")) {
    return true;
  }
  return false;
}
